# cgxsh
Command-line access to the controller-based CloudGenix ION Troubleshooting Toolkit.

#### Synopsis
This is a placeholder for the soon-to-be released utility. 

#### Requirements
* Active CloudGenix Account
* Python >=3.6
* Python modules:
    * cloudgenix - <http://docs.python-requests.org/en/master/>
    * fuzzywuzzy - <https://github.com/seatgeek/fuzzywuzzy/>

#### Installation
`pip install cgxsh`

#### License
MIT

#### Version
| Version | Build | Changes |
| ------- | ----- | ------- |
| **0.0.1** | **b1** | Placeholder for future release. |

## For more info
 * Get help and additional CloudGenix Documentation at <http://support.cloudgenix.com>